summaryrefslogtreecommitdiffstats
path: root/korganizer/kodaymatrix.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodaymatrix.cpp')
-rw-r--r--korganizer/kodaymatrix.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/korganizer/kodaymatrix.cpp b/korganizer/kodaymatrix.cpp
index 718cc5c0..431b4b3d 100644
--- a/korganizer/kodaymatrix.cpp
+++ b/korganizer/kodaymatrix.cpp
@@ -386,15 +386,15 @@ void KODayMatrix::mouseReleaseEvent( TQMouseEvent *e )
mSelEnd = mSelInit;
if (tmp != mSelStart) {
mSelStart = tmp;
- tqrepaint();
+ repaint();
}
} else {
mSelStart = mSelInit;
//tqrepaint only if selection has changed
if (tmp != mSelEnd) {
mSelEnd = tmp;
- tqrepaint();
+ repaint();
}
}
@@ -415,15 +415,15 @@ void KODayMatrix::mouseMoveEvent( TQMouseEvent *e )
mSelEnd = mSelInit;
if ( tmp != mSelStart ) {
mSelStart = tmp;
- tqrepaint();
+ repaint();
}
} else {
mSelStart = mSelInit;
//tqrepaint only if selection has changed
if ( tmp != mSelEnd ) {
mSelEnd = tmp;
- tqrepaint();
+ repaint();
}
}
}
@@ -564,7 +564,7 @@ void KODayMatrix::paintEvent( TQPaintEvent * )
TQColorGroup cg = tqpalette().active();
- p.tqbegin( &pm, this );
+ p.begin( &pm, this );
pm.fill( cg.base() );
// draw topleft frame
@@ -386,15 +386,15 @@ void KODayMatrix::mouseReleaseEvent( TQMouseEvent *e )
} else {
mSelStart = mSelInit;
- //tqrepaint only if selection has changed
+ //repaint only if selection has changed
if (tmp != mSelEnd) {
mSelEnd = tmp;
@@ -415,15 +415,15 @@ void KODayMatrix::mouseMoveEvent( TQMouseEvent *e )
} else {
mSelStart = mSelInit;
- //tqrepaint only if selection has changed
+ //repaint only if selection has changed
if ( tmp != mSelEnd ) {
mSelEnd = tmp;